summaryrefslogtreecommitdiffstats
path: root/libk3b/tools/k3btoolbutton.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
commitd8cc8bdfa7fa624a526d5aa1626974e1444cb799 (patch)
treef295f1c545b319963d5357af79fe08991d8141d9 /libk3b/tools/k3btoolbutton.h
parent2a39a080579fb52a2599c02b2939795385b89093 (diff)
downloadk3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.tar.gz
k3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.zip
TQt4 port k3b
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1233803 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/tools/k3btoolbutton.h')
-rw-r--r--libk3b/tools/k3btoolbutton.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libk3b/tools/k3btoolbutton.h b/libk3b/tools/k3btoolbutton.h
index fe96e4c..707801f 100644
--- a/libk3b/tools/k3btoolbutton.h
+++ b/libk3b/tools/k3btoolbutton.h
@@ -18,29 +18,29 @@
#include "k3b_export.h"
-#include <qtoolbutton.h>
+#include <tqtoolbutton.h>
-class QPainter;
-class QEvent;
+class TQPainter;
+class TQEvent;
/**
* the K3bToolButton is an enhanced QToolButton which adds two functionalities:
* <li>A delayed popup menu is shown immiadetely once the mouse is dragged downwards
* much like the KToolBarButton
* <li>If a popup menu is set a little arrow indicates this.
*/
-class LIBK3B_EXPORT K3bToolButton : public QToolButton
+class LIBK3B_EXPORT K3bToolButton : public TQToolButton
{
public:
- K3bToolButton( QWidget* parent = 0 );
+ K3bToolButton( TQWidget* tqparent = 0 );
~K3bToolButton();
void setInstantMenu( bool );
protected:
- virtual void drawButton( QPainter* );
- virtual bool eventFilter( QObject*, QEvent* );
+ virtual void drawButton( TQPainter* );
+ virtual bool eventFilter( TQObject*, TQEvent* );
private:
class Private;
@@ -18,29 +18,29 @@
/**
- * the K3bToolButton is an enhanced QToolButton which adds two functionalities:
+ * the K3bToolButton is an enhanced TQToolButton which adds two functionalities:
* <li>A delayed popup menu is shown immiadetely once the mouse is dragged downwards
* much like the KToolBarButton